<?php
if ( ! function_exists( 'wpj_insert_badge_order' ) ) {
	function wpj_insert_badge_order( $args = array() ) {
		global $wpdb;

		// Badge nr
		$badge_nr = ! empty( $args['badge_nr'] ) ? $args['badge_nr'] : WPJ_Form::get( 'badge_nr' );

		// Price
		$price = ! empty( $args['price'] ) ? $args['price'] : WPJ_Form::get( 'price' );

		// Payment type
		$badge_payment_type = ! empty( $args['badge_payment_type'] ) ? $args['badge_payment_type'] : WPJ_Form::get( 'badge_payment_type', 0 );

		// User info
		$user_id = ! empty( $args['user_id'] ) ? $args['user_id'] : get_current_user_id();

		// Date info
		$date_made = ! empty( $args['date_made'] ) ? $args['date_made'] : current_time( 'timestamp', 1 );

		// Payment info
		$payment_status  = ! empty( $args['payment_status'] ) ? $args['payment_status'] : 'pending';
		$payment_gateway = ! empty( $args['payment_gateway'] ) ? $args['payment_gateway'] : WPJ_Form::get( 'pay_for_item' );

		// Currency
		$currency = ! empty( $args['currency'] ) ? $args['currency'] : apply_filters( 'wpjobster_take_allowed_currency_' . $payment_gateway, '' );
		if ( empty( $currency ) ) $currency = wpj_get_site_curreny();

		// Final order price
		if ( $currency )
			$payable_amount_exchanged = wpj_number_format_special_exchange( floatval( wpj_get_badge_info( 'wpj_badge_price', $badge_nr ) ), '1', $currency );
		else
			$payable_amount_exchanged = wpj_number_format_special_exchange( floatval( wpj_get_badge_info( 'wpj_badge_price', $badge_nr ) ) );

		// Insert order to database
		$wpdb->insert(
			$wpdb->prefix . 'job_badge_orders',
			array(
				'user_id'          => $user_id,
				'badge_nr'         => $badge_nr,
				'description'      => wpj_get_badge_info( 'wpj_badge_text', $badge_nr ),
				'icon'             => wpj_get_badge_info( 'wpj_badge_icon', $badge_nr ),
				'price'            => floatval( wpj_get_badge_info( 'wpj_badge_price', $badge_nr ) ),
				'min_rating'       => wpj_get_badge_info( 'wpj_badge_min_rating', $badge_nr ),
				'min_reviews'      => wpj_get_badge_info( 'wpj_badge_min_reviews', $badge_nr ),
				'date_made'        => $date_made,
				'payment_type'     => $badge_payment_type,
				'payment_amount'   => floatval( $price ),
				'payment_currency' => $currency,
				'payment_status'   => $payment_status,
				'payment_gateway'  => $payment_gateway
			),
			array( '%d', '%d', '%s', '%s', '%f', '%d', '%d', '%d', '%d', '%f', '%s', '%s', '%s' )
		);

		$orderid = $wpdb->insert_id;

		do_action( 'wpj_after_insert_badge_order', $orderid );

		// Insert payment to database
		$wpdb->insert(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'         => $payment_status == 'completed' ? 1 : 0,
				'payment_gateway'        => $payment_gateway,
				'payment_type'           => 'badge',
				'payment_type_id'        => $orderid,
				'fees'                   => 0,
				'amount'                 => floatval( wpj_get_badge_info( 'wpj_badge_price', $badge_nr ) ),
				'datemade'               => current_time( 'timestamp', 1 ),
				'tax'                    => 0,
				'currency'               => wpj_get_site_default_curreny(),
				'final_amount'           => floatval( wpj_get_badge_info( 'wpj_badge_price', $badge_nr ) ),
				'final_amount_exchanged' => $payable_amount_exchanged,
				'final_amount_currency'  => $currency,
			),
			array( '%d', '%s', '%s', '%d', '%f', '%f', '%d', '%f', '%s', '%f', '%f', '%s' )
		);

		return $orderid;
	}
}

if ( ! function_exists( 'wpj_get_badge_info' ) ) {
	function wpj_get_badge_info( $return = '', $badge_nr = '' ) {
		$badges_data = wpj_get_option( 'badge-list-settings' );

		if ( $return && is_numeric( $badge_nr ) ) return $badges_data[$return][$badge_nr];
		if ( $return ) return $badges_data[$return];

		return $badges_data;
	}
}

if ( ! function_exists( 'wpj_get_badge_order_by' ) ) {
	function wpj_get_badge_order_by( $column_name = '', $val = '' ) {
		global $wpdb;

		$val = esc_sql( $val );

		if ( is_numeric( $val ) )
			return $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}job_badge_orders WHERE " . $column_name . " = " . $val );

		return false;
	}
}

if ( ! function_exists( 'wpj_get_badge_order_id_by_number_and_user' ) ) {
	function wpj_get_badge_order_id_by_number_and_user( $badge_nr = '', $uid = '' ) {
		global $wpdb;

		if ( ! $uid ) $uid = get_current_user_id();

		if ( is_numeric( $badge_nr ) && is_numeric( $uid ) )
			return $wpdb->get_var( $wpdb->prepare( "SELECT id FROM {$wpdb->prefix}job_badge_orders WHERE badge_nr = %d AND user_id = %d", $badge_nr, $uid ) );

		return false;
	}
}

if ( ! function_exists( 'wpj_display_user_badge_icons' ) ) {
	function wpj_display_user_badge_icons( $uid = '' ) {

		if ( ! $uid ) $uid = wpj_get_user_id();

		$user_badge = get_user_meta( $uid, 'user_badge', true );
		if ( $user_badge && ! is_array( $user_badge ) ) $user_badge = array( $user_badge );

		$tooltip_postition = is_rtl() ? 'top right' : 'top center';

		$badges_data = wpj_get_badge_info();

		if ( wpj_get_option( 'wpjobster_enable_badges_sale' ) == 'yes' && apply_filters( 'hide_for_buyers', true, $uid ) ) {

			if ( $badges_data && is_array( $badges_data ) ) {
				foreach ( $badges_data['redux_repeater_data'] as $key => $badge ) {
					if ( $user_badge && in_array( $key, $user_badge ) ) {

						wpj_get_template( 'elements/user/user-badge-icons-template.php', array(
							'uid'               => $uid,
							'tooltip_postition' => $tooltip_postition,
							'icon'              => $badges_data['wpj_badge_icon'][$key],
							'text'              => $badges_data['wpj_badge_text'][$key],
							'badges_data'       => $badges_data,
							'user_badge'        => $user_badge
						) );

					}
				}
			}

			if ( get_current_user_id() == $uid ) {
				wpj_get_template( 'elements/user/user-badge-icons-template.php', array(
					'uid'               => $uid,
					'tooltip_postition' => $tooltip_postition,
					'icon'              => 'plus',
					'text'              => __( 'Click to buy more badges', 'wpjobster' ),
					'link'              => get_permalink( wpj_get_option( 'wpjobster_badges_page_id' ) ),
					'badge'             => $badge,
					'user_badge'        => $user_badge
				) );
			}

		}

	}
}