<?php class WPJ_Badge {

	public function __construct( $payment_gateway = '' ) {
		if ( ! $payment_gateway ) $payment_gateway = WPJ_Form::get( 'pay_for_item' );

		add_action( "wpjobster_badge_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_badge_payment_failed",  array( $this, "payment_failed" ), 10, 5 );
		add_action( "wpjobster_badge_payment_other",   array( $this, "payment_other" ), 10, 6 );
	}

	public function insert_order( $payment_gateway = '' ) {
		// Get current order
		if ( ! empty( $_GET['oid'] ) && isset( $_GET['process_pending'] ) ) $oid = $_GET['oid'];
		else $oid = 0;

		// Insert order
		if ( $oid == 0 ) $oid = wpj_insert_badge_order( array( 'payment_gateway' => $payment_gateway ) );

		// Get the new order
		$order_details = wpj_get_badge_order_by( 'id', $oid );

		// Action
		do_action( 'wpj_after_new_badge_order', $order_details );

		// Return
		return $order_details;
	}

	public function payment_process( $oid, $payment_gateway_slug, $details, $response, $redirect = 'yes' ) {
		// Get feature order
		$badge_order = wpj_get_badge_order_by( 'id', $oid );

		// Start the payment process
		if ( isset( $badge_order->payment_status ) && $badge_order->payment_status != 'completed' ) {
			global $wpdb;

			$update = true;

			// Assign badge to user
			if ( ! is_demo_user() ) {
				$current_badges = get_user_meta( $badge_order->user_id, 'user_badge', true );

				if ( $current_badges ) {
					array_push( $current_badges, $badge_order->badge_nr );
					$badges = array_unique( $current_badges );

				} else $badges = array( $badge_order->badge_nr );

				if ( $badges && $badge_order->payment_gateway == 'credits' && $badge_order->price <= wpj_get_user_credit( $badge_order->user_id ) )
					wpj_update_user_credit( $badge_order->user_id, wpj_get_user_credit( $badge_order->user_id ) - $badge_order->price );

				if ( $badge_order->payment_gateway == 'credits' && $badge_order->price > wpj_get_user_credit( $badge_order->user_id ) )
					$update = false;

				if ( $badges && $update )
					update_user_meta( $badge_order->user_id, 'user_badge', $badges );
				else
					delete_user_meta( $badge_order->user_id, 'user_badge' );

			} else $update = false;

			if ( $update ) {

				// Update order payment details
				$wpdb->update(
					$wpdb->prefix . 'job_badge_orders',
					array(
						'payment_status'   => 'completed',
						'payment_response' => $response,
						'payment_date'     => current_time( 'timestamp', 1 )
					),
					array(
						'id' => $oid
					)
				);

				// Send emails
				wpj_notify_user_translated( 'badge_new', $badge_order->user_id, array(
					'##payment_gateway##' => $badge_order->payment_gateway,
					'##badge_title##'     => $badge_order->description,
					'##badge_price##'     => wpj_show_price( $badge_order->price )
				) );

				wpj_notify_user_translated( 'badge_admin_new', 'admin', array(
					'##username##'        => wpj_get_user_display_type( $badge_order->user_id ),
					'##payment_gateway##' => $badge_order->payment_gateway,
					'##badge_title##'     => $badge_order->description,
					'##badge_price##'     => wpj_show_price( $badge_order->price )
				) );

				// Save log
				$payment_row  = wpj_get_payment( array( 'payment_type_id' => $oid, 'payment_type' => 'badge' ) );
				$final_amount = $payment_row ? $payment_row->final_amount : $badge_order->payment_amount;

				wpj_add_history_log( array(
					'tp'        => '0',
					'reason'    => sprintf( __( 'Badge: %s', 'wpjobster' ), $badge_order->description ),
					'amount'    => $badge_order->price,
					'uid'       => $badge_order->user_id,
					'oid'       => $oid,
					'rid'       => 26,
					'details'   => $badge_order->description,
					'payed_amt' => $badge_order->payment_currency . '|' . $badge_order->price
				) );

				// Update payment
				$wpdb->update(
					$wpdb->prefix . 'job_payment_received',
					array(
						'payment_status'   => 'completed',
						'payment_details'  => $details,
						'payment_response' => $response,
						'payment_made_on'  => current_time( 'timestamp', 1 )
					),
					array(
						'payment_type_id' => $oid,
						'payment_type'    => 'badge'
					)
				);

				// Action
				do_action( 'wpj_badge_payment_completed', $oid );

			}
		}

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=badge" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'badge' ) );
		}
	}

	public function payment_failed( $oid, $gateway_slug, $details = '', $response = '', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_badge_orders',
			array(
				'payment_status'   => 'cancelled',
				'payment_date'     => current_time( 'timestamp', 1 ),
				'payment_response' => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => 'cancelled',
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'badge'
			)
		);

		// Action
		do_action( 'wpj_after_order_is_cancelled', $oid, 'badge' );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=badge" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'badge' ) );
		}
	}

	public function payment_other( $oid, $gateway_slug, $details = '', $response = '', $status = 'processing', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_badge_orders',
			array(
				'payment_status'   => $status,
				'payment_date'     => current_time( 'timestamp', 1 ),
				'payment_response' => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'badge'
			)
		);

		// Action
		do_action( 'wpjobster_badge_payment_other', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=badge" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'badge' ) );
		}
	}

}