<?php class WPJ_Feature {

	public function __construct( $payment_gateway = '' ) {
		if ( ! $payment_gateway ) $payment_gateway = WPJ_Form::get( 'pay_for_item' );

		add_action( "wpjobster_feature_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_feature_payment_failed",  array( $this, "payment_failed" ), 10, 5 );
		add_action( "wpjobster_feature_payment_other",   array( $this, "payment_other" ), 10, 6 );
	}

	public function insert_order( $payment_gateway = '' ) {
		// Get current order
		if ( ! empty( $_GET['oid'] ) && isset( $_GET['process_pending'] ) ) $oid = $_GET['oid'];
		else $oid = 0;

		// Insert order
		if ( $oid == 0 ) $oid = wpj_insert_feature_order( array( 'payment_gateway' => $payment_gateway ) );

		// Get the new order
		$order_details = wpj_get_featured_order_by( 'id', $oid );

		// Action
		do_action( 'wpj_after_new_feature_order', $order_details );

		// Return
		return $order_details;
	}

	public function payment_process( $oid, $payment_gateway_slug, $details, $response, $redirect = 'yes' ) {
		// Get feature order
		$featured_order = wpj_get_featured_order_by( 'id', $oid );

		// Start the payment process
		if ( isset( $featured_order->payment_status ) && $featured_order->payment_status != 'completed' ) {
			global $wpdb;

			// Update order payment details
			$wpdb->update(
				$wpdb->prefix . 'job_featured_orders',
				array(
					'payment_status'                 => 'completed',
					'payment_gateway_transaction_id' => $details,
					'payment_response'               => $response,
					'paid_on'                        => current_time( 'timestamp', 1 )
				),
				array(
					'id' => $oid
				)
			);

			// Mark job as featured on homepage
			if ( strpos( $featured_order->feature_pages, 'h' ) !== false )
				wpj_mark_job_as_featured( 'homepage', $featured_order->job_id );

			// Mark job as featured on category
			if ( strpos( $featured_order->feature_pages, 'c' ) !== false )
				wpj_mark_job_as_featured( 'category', $featured_order->job_id );

			// Mark job as featured on subcategory
			if ( strpos( $featured_order->feature_pages, 's') !== false )
				wpj_mark_job_as_featured( 'subcategory', $featured_order->job_id );

			// Send emails
			wpj_notify_user_translated( 'featured_new', $featured_order->user_id, array(
				'##job_link##'          => urldecode( get_permalink( $featured_order->job_id ) ),
				'##job_name##'          => get_the_title( $featured_order->job_id ),
				'##all_featured_info##' => wpj_get_feature_info_for_email( $featured_order->job_id )
			) );

			wpj_notify_user_translated( 'featured_admin_new', 'admin', array(
				'##username##'          => wpj_get_user_display_type( $featured_order->user_id ),
				'##job_link##'          => urldecode( get_permalink( $featured_order->job_id ) ),
				'##job_name##'          => get_the_title( $featured_order->job_id ),
				'##all_featured_info##' => wpj_get_feature_info_for_email( $featured_order->job_id )
			) );

			// Save log
			$payment_row  = wpj_get_payment( array( 'payment_type_id' => $oid, 'payment_type' => 'feature' ) );
			$final_amount = $payment_row ? $payment_row->final_amount : $featured_order->payable_amount;

			$reason = __( 'Feature job', 'wpjobster' ) . ': <a href="' . get_permalink( $featured_order->job_id ) . '">' . get_the_title( $featured_order->job_id ) . '</a>';

			wpj_add_history_log( array(
				'tp'        => '0',
				'reason'    => $reason,
				'amount'    => $featured_order->featured_amount,
				'uid'       => $featured_order->user_id,
				'oid'       => $oid,
				'rid'       => 10,
				'details'   => $featured_order->job_id,
				'payed_amt' => $featured_order->currency . '|' . $featured_order->featured_amount
			) );

			// Update payment
			$wpdb->update(
				$wpdb->prefix . 'job_payment_received',
				array(
					'payment_status'   => 'completed',
					'payment_details'  => $details,
					'payment_response' => $response,
					'payment_made_on'  => current_time( 'timestamp', 1 )
				),
				array(
					'payment_type_id' => $oid,
					'payment_type'    => 'feature'
				)
			);

			// Action
			do_action( 'wpj_feature_payment_completed', $oid );

		}

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=feature" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'feature', $oid, 'success' ) );
		}
	}

	public function payment_failed( $oid, $gateway_slug, $details = '', $response = '', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_featured_orders',
			array(
				'payment_status'                 => 'cancelled',
				'paid_on'                        => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => 'cancelled',
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'feature'
			)
		);

		// Action
		do_action( 'wpj_after_order_is_cancelled', $oid, 'feature' );
		do_action( 'wpj_feature_payment_failed', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=feature" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'feature', $oid, 'fail' ) );
		}
	}

	public function payment_other( $oid, $gateway_slug, $details = '', $response = '', $status = 'processing', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_featured_orders',
			array(
				'payment_status'                 => $status,
				'paid_on'                        => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'feature'
			)
		);

		// Action
		do_action( 'wpjobster_feature_payment_other', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=feature" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'feature', $oid, 'success' ) );
		}
	}

}