<?php class WPJ_Job_Purchase {

	public function __construct( $payment_gateway = '' ) {
		if ( ! $payment_gateway ) $payment_gateway = WPJ_Form::get( 'pay_for_item' );

		add_action( "wpjobster_job_purchase_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_job_purchase_payment_failed",  array( $this, "payment_failed" ), 10, 5 );
		add_action( "wpjobster_job_purchase_payment_other",   array( $this, "payment_other" ), 10, 6 );
	}

	public function insert_order( $payment_gateway = '' ) {
		// Get current order
		if ( ! empty( $_GET['oid'] ) && isset( $_GET['process_pending'] ) ) $oid = $_GET['oid'];
		else $oid = 0;

		// Insert order if is new
		if ( $oid == 0 ) $oid = wpj_insert_job_purchase_order( array( 'payment_gateway' => $payment_gateway ) );

		// Get the new order
		$order_details = wpj_get_order( $oid );

		// Action
		do_action( 'wpj_after_new_job_order', $order_details );

		// Return
		return $order_details;
	}

	public function payment_process( $oid, $gateway_slug, $details, $response, $redirect = 'yes' ) {
		// Get job purchase order
		$order_details = wpj_get_order( $oid );

		// Accept custom offer
		if ( wpj_is_custom_offer( $order_details->pid ) )
			wpj_accept_custom_offer( $order_details->pid, $oid, $order_details->uid, wpj_get_seller_id( $order_details ) );

		// Start the payment process
		if ( isset( $order_details->payment_status ) && $order_details->payment_status != 'completed' ) {
			global $wpdb;

			// Update order payment details
			$wpdb->update(
				$wpdb->prefix . 'job_orders',
				array(
					'payment_status'   => 'completed',
					'payment_details'  => $details,
					'payment_response' => $response,
					'closed'           => 0,
					'date_closed'      => ''
				),
				array(
					'id' => $oid
				)
			);

			// Insert order to ratings table
			$wpdb->insert(
				$wpdb->prefix . 'job_ratings',
				array(
					'orderid' => $oid,
					'uid'     => wpj_get_seller_id( $order_details ),
					'pid'     => $order_details->pid
				),
				array( '%d', '%d', '%d' )
			);

			// Insert to chatbox
			$row_exist = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM {$wpdb->prefix}job_chatbox WHERE datemade = %d AND uid = 0 AND oid = %d", current_time( 'timestamp', 1 ), $oid ) );

			if ( ! $row_exist ) {
				$wpdb->insert(
					$wpdb->prefix . 'job_chatbox',
					array(
						'datemade' => current_time( 'timestamp', 1 ),
						'uid'      => '0',
						'oid'      => $oid,
						'content'  => ''
					),
					array( '%d', '%s', '%d', '%s' )
				);

				// Update notifications
				$this_notification = $wpdb->insert_id;

				wpj_update_user_notifications( array(
					'user1'       => wpj_get_seller_id( $order_details ),
					'user2'       => $order_details->uid,
					'type'        => wpj_is_custom_offer( $order_details->pid ) ? 'messages' : 'notifications',
					'number'      => +1,
					'notify_id'   => $this_notification,
					'notify_type' => wpj_is_custom_offer( $order_details->pid ) ? 'custom_offer_paid_new' : 'purchased_job',
					'order_id'    => $oid
				) );
			}

			// Send emails
			$array_to_send = array(
				'##mc_gross##'              => $order_details->mc_gross,
				'##processing_fees##'       => $order_details->processing_fees,
				'##tax_amount##'            => $order_details->tax_amount,
				'##transaction_number##'    => wpj_camouflage_oid( $oid, current_time( 'timestamp', 1 ) ),
				'##transaction_page_link##' => wpj_get_order_link( $oid ),
				'##job_name##'              => $order_details->job_title,
				'##job_link##'              => urldecode( get_permalink( $order_details->pid ) ),
				'##sender_username##'       => get_current_user_id() == $order_details->uid ? wpj_get_user_display_type( $order_details->uid ) : wpj_get_user_display_type( wpj_get_seller_id( $order_details ) )
			);

			$array_to_send_buyer  = $array_to_send + array( '##sender_username##' => wpj_get_user_display_type( wpj_get_seller_id( $order_details ) ) );
			$array_to_send_seller = $array_to_send + array( '##sender_username##' => wpj_get_user_display_type( $order_details->uid ) );

			wpj_notify_user_translated( 'purchased_buyer', $order_details->uid, $array_to_send_buyer );
			wpj_notify_user_translated( 'purchased_seller', wpj_get_seller_id( $order_details ), $array_to_send_seller );

			// Save log
			wpj_maintain_log( $oid );

			// Update payment
			$wpdb->update(
				$wpdb->prefix . 'job_payment_received',
				array(
					'payment_status'   => 'completed',
					'payment_details'  => $details,
					'payment_response' => $response,
					'payment_made_on'  => current_time( 'timestamp', 1 )
				),
				array(
					'payment_type_id' => $oid,
					'payment_type'    => 'job_purchase'
				)
			);

			// Action
			do_action( 'wpj_after_job_payment_is_completed', $oid, 'process' );

		}

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( wpj_get_option( "wpjobster_{$gateway_slug}_success_page" ) )
				wp_redirect( get_permalink( wpj_get_option( "wpjobster_{$gateway_slug}_success_page" ) ) . $oid );
			else
				wp_redirect( wpj_get_order_link( $oid ) );
		}
	}

	public function payment_failed( $oid, $gateway_slug, $details = '', $response = '', $redirect = 'yes' ) {
		global $wpdb;

		// Get current order
		$order_details = wpj_get_order( $oid );

		// Update order
		if ( empty( $response ) ) $response = $order_details->payment_response;
		$wpdb->update(
			$wpdb->prefix . 'job_orders',
			array(
				'payment_status'   => 'cancelled',
				'closed'           => 1,
				'date_closed'      => current_time( 'timestamp', 1 ),
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => 'cancelled',
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'job_purchase'
			)
		);

		// Action
		do_action( 'wpj_after_order_is_cancelled', $oid, 'job_purchase' );
		do_action( 'wpjobster_job_payment_failed', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( wpj_get_option( "wpjobster_{$gateway_slug}_failure_page" ) ) wp_redirect( get_permalink( wpj_get_option( "wpjobster_{$gateway_slug}_failure_page" ) ) );
			else wp_redirect( wpj_get_order_link( $oid ) );
		}
	}

	public function payment_other( $oid, $gateway_slug, $details, $response, $status = 'processing', $redirect = 'yes' ) {
		global $wpdb;

		// Get current order
		$order_details = wpj_get_order( $oid );

		// Update order
		if ( empty( $response ) ) $response = $order_details->payment_response;
		$wpdb->update(
			$wpdb->prefix . 'job_orders',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'job_purchase'
			)
		);

		// Action
		do_action( 'wpjobster_job_payment_other', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( wpj_get_option( "wpjobster_{$gateway_slug}_success_page" ) ) wp_redirect( get_permalink( wpj_get_option( "wpjobster_{$gateway_slug}_success_page" ) ) );
			else wp_redirect( wpj_get_order_link( $oid ) );
		}
	}

}