<?php class WPJ_Subscription {

	public function __construct( $payment_gateway = '' ) {
		if ( ! $payment_gateway ) $payment_gateway = WPJ_Form::get( 'pay_for_item' );

		add_action( "wpjobster_subscription_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_subscription_payment_failed",  array( $this, "payment_failed" ), 10, 5 );
		add_action( "wpjobster_subscription_payment_other",   array( $this, "payment_other" ), 10, 6 );
	}

	public function insert_order( $payment_gateway = '' ) {
		// Get current order
		if ( ! empty( $_GET['oid'] ) && isset( $_GET['process_pending'] ) ) $oid = $_GET['oid'];
		else $oid = 0;

		// Insert order
		if ( $oid == 0 ) $oid = wpj_insert_subscription_order( array( 'payment_gateway' => $payment_gateway ) );

		// Get the new order
		$order_details = wpj_get_subscription_order_by( 'id', $oid, 'all' );

		// Action
		do_action( 'wpj_after_new_subscription_order', $order_details );

		// Return
		return $order_details;
	}

	public function payment_process( $oid, $payment_gateway_slug, $details, $response, $redirect = 'yes' ) {
		// Get subscription order
		$order_details = wpj_get_subscription_order_by( 'id', $oid, 'all' );

		// Start the payment process
		if ( isset( $order_details->payment_status ) && $order_details->payment_status != 'completed' ) {
			global $wpdb;

			// Get user
			$uid = $order_details->user_id;

			// Update order
			$wpdb->update(
				$wpdb->prefix . 'job_subscription_orders',
				array(
					'payment_status'                 => 'completed',
					'subscription_status'            => 'active',
					'payment_date'                   => current_time( 'timestamp', 1 ),
					'payment_gateway_transaction_id' => $details ? $details : $uid,
					'payment_response'               => $response,
					'profile_id'                     => $uid
				),
				array(
					'id' => $oid
				)
			);

			// Activate subscription
			wpj_activate_subscription_order( $oid );

			// Update payment
			$wpdb->update(
				$wpdb->prefix . 'job_payment_received',
				array(
					'payment_status'   => 'completed',
					'payment_details'  => $details,
					'payment_response' => $response,
					'payment_made_on'  => current_time( 'timestamp', 1 )
				),
				array(
					'payment_type_id' => $oid,
					'payment_type'    => 'subscription'
				)
			);

			// Action
			do_action( 'wpjobster_subscription_payment_completed', $oid );

		}

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=subscription" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'subscription', '', 'thankyou', 'success' ) );
		}

	}

	public function payment_failed( $oid, $gateway_slug, $details = 'Subscription cancelled', $response = '', $redirect = 'yes' ) {
		global $wpdb;

		// Get subscription order
		$order_details = wpj_get_subscription_order_by( 'id', $oid, 'all' );

		// Get user
		$uid = $order_details->user_id;

		// Get subscription
		$subscription = wpj_get_subscription_by_uid( $uid );

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => 'cancelled',
				'payment_response' => $response,
				'payment_details'  => $details,
				'payment_made_on'  => current_time( 'timestamp', 1 )
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'subscription'
			)
		);

		// Send emails
		wpj_notify_user_translated( 'subscription_cancel', $uid, array(
			'##username##'                    => wpj_get_user_display_type( $uid ),
			'##amount_updated##'              => $order_details->amount,
			'##current_subscription_level##'  => wpj_translate_string( $order_details->level ),
			'##current_subscription_period##' => wpj_translate_string( $order_details->plan ),
			'##current_subscription_amount##' => $order_details->amount
		) );

		wpj_notify_user_translated( 'admin_cancel_subscription', 'admin', array(
			'##username##'                    => wpj_get_user_display_type( $uid ),
			'##amount_updated##'              => $order_details->amount,
			'##current_subscription_level##'  => wpj_translate_string( $order_details->level ),
			'##current_subscription_period##' => wpj_translate_string( $order_details->plan ),
			'##current_subscription_amount##' => $order_details->amount
		) );

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_subscription_orders',
			array(
				'payment_status'                 => 'cancelled',
				'subscription_status'            => 'inactive',
				'payment_date'                   => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response,
				'profile_id'                     => $uid
			),
			array(
				'id' => $oid
			)
		);

		// Action
		do_action( 'wpj_after_order_is_cancelled', $oid, 'subscription' );
		do_action( 'wpj_subscription_payment_failed', $oid );

		// Checks
		wpj_do_user_level_extras_check( $uid );
		wpj_do_user_level_extras_price_check( $uid );
		wpj_do_user_level_job_price_check( $uid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=subscription" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'subscription', '', 'sub_error', 'cancelled' ) );
		}
	}

	public function payment_other( $oid, $gateway_slug, $details = 'Subscription processing', $response = '', $status = 'processing', $redirect = 'yes' ) {
		global $wpdb;

		// Get subscription order
		$order_details = wpj_get_subscription_order_by( 'id', $oid, 'all' );

		// Get user
		$uid = $order_details->user_id;

		// Get subscription
		$subscription = wpj_get_subscription_by_uid( $uid );

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details,
				'payment_made_on'  => current_time( 'timestamp', 1 )
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'subscription'
			)
		);

		// Update order payment details
		$wpdb->update(
			$wpdb->prefix . 'job_subscription_orders',
			array(
				'payment_status'                 => $status,
				'subscription_status'            => 'inactive',
				'payment_date'                   => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response,
				'profile_id'                     => $uid
			),
			array(
				'id' => $oid
			)
		);

		// Action
		do_action( 'wpj_subscription_payment_other', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=subscription" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'subscription', '', 'thankyou', 'success' ) );
		}
	}

}