<?php class WPJ_Tips {

	public function __construct( $payment_gateway = '' ) {
		if ( ! $payment_gateway ) $payment_gateway = WPJ_Form::get( 'pay_for_item' );

		add_action( "wpjobster_tips_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_tips_payment_failed",  array( $this, "payment_failed" ), 10, 5 );
		add_action( "wpjobster_tips_payment_other",   array( $this, "payment_other" ), 10, 6 );
	}

	public function insert_order( $payment_gateway = '' ) {
		// Insert order
		$oid = wpj_insert_tips_order( array( 'payment_gateway' => $payment_gateway ) );

		// Get the new order
		$order_details = wpj_get_tips_order_by( 'id', $oid );

		// Action
		do_action( 'wpj_after_new_tips_order', $order_details );

		// Return
		return $order_details;
	}

	public function payment_process( $oid, $payment_gateway_slug, $details, $response, $redirect = 'yes' ) {
		// Get current order
		$tips_order = wpj_get_tips_order_by( 'id', $oid );

		// Start the payment process
		if ( isset( $tips_order->payment_status ) && $tips_order->payment_status != 'completed' ) {
			global $wpdb;

			// Get parent order
			$parent_order_id      = $tips_order->order_id;
			$parent_order_details = wpj_get_order( $parent_order_id );

			// Get author ID
			$buyer_id  = $tips_order->user_id;
			$seller_id = wpj_get_seller_id( $parent_order_details );

			// Get tip
			$tips = json_decode( $parent_order_details->tips );
			$tip  = $tips[$tips_order->tips_id];

			// Set tip as paid
			$tip->paid = true;

			// Currency
			$currency = $tips_order->currency;

			// Processing fee
			$processing_fees = wpj_get_site_processing_fee_by_amount( $tip->amount, 0, 0 );
			if ( $processing_fees ) $tip->processing_fees = $processing_fees;

			// Tax
			$tax = wpj_get_site_tax_by_amount( $tip->amount, 0, 0, $processing_fees );
			if ( $tax ) $tip->tax = $tax;

			// Update order payment details
			$wpdb->update(
				$wpdb->prefix . 'job_tips_orders',
				array(
					'payment_status'                 => 'completed',
					'paid_on'                        => current_time( 'timestamp', 1 ),
					'payment_gateway_transaction_id' => $details,
					'payment_response'               => $response
				),
				array(
					'id' => $oid
				)
			);

			// Update tips inside order
			wpj_update_order_meta( $parent_order_id, 'tips', json_encode( $tips ) );

			// Send emails
			wpj_notify_user_translated( 'tips_paid_new', $seller_id, array(
				'##sender_username##'       => wpj_get_user_display_type( $buyer_id ),
				'##transaction_number##'    => wpj_camouflage_oid( $parent_order_details->id, $parent_order_details->date_made ),
				'##transaction_page_link##' => wpj_get_order_link( $parent_order_id ),
				'##job_name##'              => $parent_order_details->job_title,
				'##job_link##'              => urldecode( get_permalink( $parent_order_details->pid ) )
			) );

			// Save log for buyer
			$reason = __( 'Tips', 'wpjobster' ) . ': <a href="' . get_permalink( $parent_order_details->pid ) . '">' . $parent_order_details->job_title . $tip->reason . '</a>';
			wpj_add_history_log( array(
				'tp'        => '0',
				'reason'    => $reason,
				'amount'    => $tip->amount,
				'uid'       => $buyer_id,
				'oid'       => $parent_order_id,
				'rid'       => 24,
				'details'   => $oid,
				'payed_amt' => $currency . "|" . wpj_number_format_special_exchange( $tip->amount, 1, $currency )
			) );

			// Save fee log for buyer
			if ( $processing_fees ) {
				$reason = __( 'Processing fee for tips', 'wpjobster' ) . ': <a href="' . get_permalink( $parent_order_details->pid ) . '">' . $parent_order_details->job_title . $tip->reason . '</a>';
				wpj_add_history_log( array(
					'tp'        => '0',
					'reason'    => $reason,
					'amount'    => $processing_fees,
					'uid'       => $buyer_id,
					'oid'       => $parent_order_id,
					'rid'       => 22,
					'details'   => $oid,
					'payed_amt' => $currency . "|" . wpj_number_format_special_exchange( $processing_fees, 1, $currency )
				) );
			}

			// Save tax log for buyer
			if ( $tax ) {
				$reason = __( 'Tax for tips', 'wpjobster' ) . ': <a href="' . get_permalink( $parent_order_details->pid ) . '">' . $parent_order_details->job_title . $tip->reason . '</a>';
				wpj_add_history_log( array(
					'tp'        => '0',
					'reason'    => $reason,
					'amount'    => $tax,
					'uid'       => $buyer_id,
					'oid'       => $parent_order_id,
					'rid'       => 23,
					'details'   => $oid,
					'payed_amt' => $currency . "|" . wpj_number_format_special_exchange( $tax, 1, $currency )
				) );
			}

			// Save collected log for seller
			$reason = __( 'Payment collected for tips', 'wpjobster' ) . ': <a href="' . get_permalink( $parent_order_details->pid ) . '">' . $parent_order_details->job_title . $tip->reason . '</a>';
			wpj_add_history_log( array(
				'tp'        => '2',
				'reason'    => $reason,
				'amount'    => $tip->amount,
				'uid'       => $seller_id,
				'oid'       => $parent_order_id,
				'rid'       => 25,
				'details'   => $oid,
				'payed_amt' => $currency . '|' . wpj_number_format_special_exchange( $tip->amount, 1, $currency )
			) );

			// Insert to chatbox
			$row_exist = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM {$wpdb->prefix}job_chatbox WHERE datemade = %d AND uid = -37 AND oid = %d", current_time( 'timestamp', 1 ), $parent_order_id ) );

			if ( ! $row_exist ) {
				$wpdb->insert(
					$wpdb->prefix . 'job_chatbox',
					array(
						'datemade' => current_time( 'timestamp', 1 ),
						'uid'      => -37,
						'oid'      => $parent_order_id,
						'content'  => $oid
					),
					array( '%d', '%s', '%d', '%s' )
				);

				// Update notifications
				$this_notification = $wpdb->insert_id;

				wpj_update_user_notifications( array(
					'user1'       => $seller_id,
					'user2'       => $buyer_id,
					'type'        => 'notifications',
					'number'      => +1,
					'notify_id'   => $this_notification,
					'notify_type' => 'tips_paid_new',
					'order_id'    => $parent_order_id
				) );
			}

			// Update payment
			$wpdb->update(
				$wpdb->prefix . 'job_payment_received',
				array(
					'payment_status'   => 'completed',
					'payment_details'  => $details,
					'payment_response' => $response,
					'payment_made_on'  => current_time( 'timestamp', 1 )
				),
				array(
					'payment_type_id' => $oid,
					'payment_type'    => 'tips'
				)
			);

			// Action
			do_action( 'wpj_tips_payment_completed', $oid );

		}

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=tips" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'tips', $parent_order_id, 'success' ) );
		}

	}

	public function payment_failed( $oid, $gateway_slug, $details = '', $response = '', $redirect = 'yes' ) {
		global $wpdb;

		$parent_order_details = wpj_get_tips_order_by( 'id', $oid );

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_tips_orders',
			array(
				'payment_status'                 => 'cancelled',
				'paid_on'                        => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => 'cancelled',
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'tips'
			)
		);

		// Action
		do_action( 'wpj_after_order_is_cancelled', $oid, 'tips' );
		do_action( 'wpj_tips_payment_failed', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=tips" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'tips', $parent_order_id, 'fail' ) );
		}
	}

	public function payment_other( $oid, $gateway_slug, $details = '', $response = '', $status = 'processing', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_tips_orders',
			array(
				'payment_status'                 => $status,
				'paid_on'                        => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'tips'
			)
		);

		// Action
		do_action( 'wpjobster_tips_payment_other', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=tips" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'tips', $parent_order_id, 'success' ) );
		}

	}

}