<?php class WPJ_Topup {

	public function __construct( $payment_gateway = '' ) {
		if ( ! $payment_gateway ) $payment_gateway = WPJ_Form::get( 'pay_for_item' );

		add_action( "wpjobster_topup_payment_success", array( $this, "payment_process" ), 10, 5 );
		add_action( "wpjobster_topup_payment_failed",  array( $this, "payment_failed" ), 10, 5 );
		add_action( "wpjobster_topup_payment_other",   array( $this, "payment_other" ), 10, 6 );
	}

	public function insert_order( $payment_gateway = '' ) {
		// Get current order
		if ( ! empty( $_GET['oid'] ) && isset( $_GET['process_pending'] ) ) $oid = $_GET['oid'];
		else $oid = 0;

		// Insert order
		if ( $oid == 0 ) $oid = wpj_insert_topup_order( array( 'payment_gateway' => $payment_gateway ) );

		// Get the new order
		$order_details = wpj_get_topup_order_by( 'id', $oid );

		// Action
		do_action( 'wpj_after_new_topup_order', $order_details );

		// Return
		return $order_details;
	}

	public function payment_process( $oid, $gateway_slug, $details, $response, $redirect = 'yes' ) {
		// Get topup order
		$topup_order = wpj_get_topup_order_by( 'id', $oid );

		// Start the payment process
		if ( isset( $topup_order->payment_status ) && $topup_order->payment_status != 'completed' ) {
			global $wpdb;

			// Get current user
			$uid = $topup_order->user_id;

			// Update order payment details
			$wpdb->update(
				$wpdb->prefix . 'job_topup_orders',
				array(
					'payment_status'                 => 'completed',
					'paid_on'                        => current_time( 'timestamp', 1 ),
					'payment_gateway_transaction_id' => $details,
					'payment_response'               => $response
				),
				array(
					'id' => $oid
				),
				array( '%s', '%d', '%s', '%s' ),
				array( '%d' )
			);

			// Increase credits
			$final_price = wpj_get_topup_package( $topup_order->package_id, 'credit' );
			if ( $topup_order->currency != wpj_get_site_curreny() ) {
				$final_price = wpj_get_exchanged_value( $final_price, wpj_get_site_default_curreny(), wpj_get_site_curreny() );
			}

			wpj_update_user_credit( $uid, wpj_get_user_credit( $uid ) + $final_price );

			// Send emails
			if ( $topup_order->payment_gateway_name == 'paypal' ) {

				wpj_notify_user_translated( 'balance_up_paypal', $uid, array(
					'##amount_updated##'             => $final_price,
					'##username##'                   => wpj_get_user_display_type( $uid ),
					'##amount_updated_in_currency##' => $topup_order->package_amount . ' ' . $topup_order->currency,
					'##payment_gateway##'            => $topup_order->payment_gateway_name
				) );

				wpj_notify_user_translated( 'balance_admin_up_paypal', 'admin', array(
					'##amount_updated##'  => $final_price,
					'##username##'        => wpj_get_user_display_type( $uid ),
					'##payment_gateway##' => $topup_order->payment_gateway_name
				) );

			} else {

				wpj_notify_user_translated( 'balance_up_topup', $uid, array(
					'##amount_updated##'             => $final_price,
					'##username##'                   => wpj_get_user_display_type( $uid ),
					'##amount_updated_in_currency##' => $topup_order->package_amount . ' ' . $topup_order->currency,
					'##payment_gateway##'            => $topup_order->payment_gateway_name
				) );

				wpj_notify_user_translated( 'balance_admin_up_topup', 'admin', array(
					'##amount_updated##'  => $final_price,
					'##username##'        => wpj_get_user_display_type( $uid ),
					'##payment_gateway##' => $topup_order->payment_gateway_name
				) );

			}

			// Activate jobs with 'no_credits' deactivation reason
			$posts = wpj_get_deactivated_jobs_by_reason( wpj_get_buyer_by_payment_type( $oid, 'topup' ), 'no_credits' );
			if ( $posts ) { foreach ( $posts as $post ) { wpj_activate_job( $post->ID ); } }

			// Save log
			$payment_row  = wpj_get_payment( array( 'payment_type_id' => $oid, 'payment_type' => 'topup' ) );
			$final_amount = $payment_row ? $payment_row->final_amount : $topup_order->package_amount;

			wpj_add_history_log( array(
				'tp'        => '1',
				'reason'    => __( 'Top Up account balance', 'wpjobster' ),
				'amount'    => $topup_order->package_amount,
				'uid'       => $uid,
				'oid'       => $oid,
				'rid'       => 12,
				'details'   => '',
				'payed_amt' => $topup_order->currency . '|' . $topup_order->package_amount
			) );

			// Update payment
			$wpdb->update(
				$wpdb->prefix . 'job_payment_received',
				array(
					'payment_status'   => 'completed',
					'payment_details'  => $details,
					'payment_response' => $response,
					'payment_made_on'  => current_time( 'timestamp', 1 )
				),
				array(
					'payment_type_id' => $oid,
					'payment_type'    => 'topup'
				)
			);

			// Action
			do_action( 'wpj_topup_payment_completed', $oid );

		}

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=topup" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'topup', $oid ) );
		}
	}

	public function payment_failed( $oid, $gateway_slug, $details = '',$response = '', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_topup_orders',
			array(
				'payment_status'                 => 'cancelled',
				'paid_on'                        => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => 'cancelled',
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'topup'
			)
		);

		// Action
		do_action( 'wpj_after_order_is_cancelled', $oid, 'topup' );
		do_action( 'wpj_topup_payment_failed', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=fail&active_tab=topup" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'topup', $oid ) );
		}
	}

	public function payment_other( $oid, $gateway_slug, $details = '', $response = '', $status = 'processing', $redirect = 'yes' ) {
		global $wpdb;

		// Update order
		$wpdb->update(
			$wpdb->prefix . 'job_topup_orders',
			array(
				'payment_status'                 => $status,
				'paid_on'                        => current_time( 'timestamp', 1 ),
				'payment_gateway_transaction_id' => $details,
				'payment_response'               => $response
			),
			array(
				'id' => $oid
			)
		);

		// Update payment
		$wpdb->update(
			$wpdb->prefix . 'job_payment_received',
			array(
				'payment_status'   => $status,
				'payment_response' => $response,
				'payment_details'  => $details
			),
			array(
				'payment_type_id' => $oid,
				'payment_type'    => 'topup'
			)
		);

		// Action
		do_action( 'wpjobster_topup_payment_other', $oid );

		// Redirect
		if ( $redirect == 'yes' ) {
			if ( isset( $_SERVER['HTTP_REFERER'] ) && strpos( $_SERVER['HTTP_REFERER'], 'page=jobster-orders' ) && strpos( $_SERVER['HTTP_REFERER'], 'admin.php' ) )
				wp_redirect( $_SERVER['HTTP_REFERER'] . "&status=success&active_tab=topup" );
			else
				wp_redirect( wpj_get_order_link_by_payment_type( 'topup', $oid ) );
		}
	}

}